# -*- coding: iso-8859-1 -*-
"""
    MoinMoin - FormMessage Macro

    @copyright: 2012 by Paul Boddie <paul@boddie.org.uk>
    @license: GNU GPL (v2 or later), see COPYING.txt for details.
"""

from MoinSupport import *
from MoinForms import parseMacroArguments

Dependencies = ['pages']

# Macro functions.

def execute(macro, args):

    """
    Execute the 'macro' with the given 'args' to produce a form field element:

      * A field name

    The following optional named arguments are also supported:

      path=PATH     The location of the field in the form section hierarchy
    """

    request = macro.request
    fmt = macro.formatter
    page = fmt.page
    _ = request.getText

    # Interpret the arguments.

    parsed_args = parseMacroArguments(args)

    # Get special arguments.

    name = None
    path = None

    for arg in parsed_args:
        if arg.startswith("name="):
            name = arg[5:]

        elif arg.startswith("path="):
            path = arg[5:]

        elif name is None:
            name = arg

    if not name:
        return showError(_("No field name specified."), request)

    # The field name is a combination of the path and the name.

    ref = "%s%s" % (path and ("%s/" % path) or "", name)

    # Obtain any request parameters corresponding to the field.

    form = get_form(request)
    value = form.get(ref, [""])[0]

    # Render the message.

    return fmt.text(value)

def showError(text, request):
    fmt = request.formatter

    output = []
    append = output.append

    append(fmt.span(on=1, attrs={"class" : "form-field-error"}))
    append(fmt.text(text))
    append(fmt.span(on=0))

    return "".join(output)

# vim: tabstop=4 expandtab shiftwidth=4
